@@ -2,7 +2,7 @@
 
 namespace apexl\Io\includes;
 
-use apexl\Config\Singleton;
+use apexl\Config\Configuration;
 use apexl\Io\middleware\accessRequest\accessRequest;
 use apexl\Io\middleware\addCorsHeaders;
 use apexl\Io\middleware\bodyParser\bodyParserController;
@@ -14,6 +14,7 @@ use apexl\Io\services\Output;
 use apexl\Io\services\pathUtility;
 use apexl\Utils\Json\Json;
 use apexl\Vault\Vault;
+use app\vendor\apexl\io\src\Io\middleware\addBuildHeader;
 use DI\Container;
 use DI\ContainerBuilder;
 use Exception;
@@ -25,6 +26,7 @@ use Psr\Http\Message\ResponseInterface as Response;
 use Slim\App;
 use Slim\Exception\HttpNotFoundException;
 use Slim\Factory\AppFactory;
+use Slim\Middleware\MethodOverrideMiddleware;
 use Whoops\Handler\JsonResponseHandler;
 use Zeuxisoo\Whoops\Slim\WhoopsMiddleware;
 
@@ -55,14 +57,13 @@ class System
 
     protected static $isInstalled = false;
 
-
     /**
      * System constructor.
      * @throws Exception
      */
     private function __construct()
     {
-        self::$config = Singleton::getInstance();
+        self::$config = Configuration::getInstance();
         self::$pathUtility = pathUtility::getInstance();
         self::$module = modules::getInstance();
         $this->defineConstants();
@@ -86,6 +87,19 @@ class System
         define('VERSION', self::$config->app->version ?? 1);
     }
 
+    public static function reset(): void
+    {
+        self::$app = null;
+        self::$instance = null;
+        self::$module = null;
+        self::$installing = null;
+        self::$config = null;
+        self::$pathUtility = null;
+        self::$routes = null;
+        self::$basePath = null;
+        self::$isInstalled = null;
+    }
+
     public static function switchDatabase($name)
     {
         $database = Vault::getInstance();
@@ -115,10 +129,11 @@ class System
         self::$app->add(bodyParserController::class);
         self::$app->add(accessRequest::class);
         self::$app->addRoutingMiddleware();
-
+        self::$app->add(new MethodOverrideMiddleware());
         $whoopsHandlers = Hook::processHook('whoopsHandlers', [new JsonResponseHandler()]);
         self::$app->add(new WhoopsMiddleware(['enable' => true], $whoopsHandlers));
         self::$app->add(addCorsHeaders::class);
+        self::$app->add(addBuildHeader::class);
 
         /**
          * Catch-all route to serve a 404 Not Found page if none of the routes match
@@ -129,8 +144,8 @@ class System
                 throw new HttpNotFoundException($request);
             } catch (Exception $e) {
                 error_log(
-                    "[IO Exception :: Routing] (Line ".$e->getLine()." | ".$e->getFile().") - ".$e->getCode(
-                    )." | ".$e->getMessage()
+                    "[IO Exception :: Routing] (Line " . $e->getLine() . " | " . $e->getFile() . ") - " . $e->getCode(
+                    ) . " | " . $e->getMessage()
                 );
                 //did we thorw a true 404? or is there an exisitng system error?
                 if (!Output::getSystemErrors()) {
@@ -183,7 +198,7 @@ class System
 
     public static function redirect($location, $status = 302): never
     {
-        header('Location: '.$location, true, $status);
+        header('Location: ' . $location, true, $status);
         exit();
     }
 
@@ -297,7 +312,7 @@ class System
     /**
      * @param $name
      * @param $data
-     * @param  int  $site
+     * @param int $site
      * @return mixed
      */
     public static function setVariable(string $name, $data, int $site = 1)
@@ -426,8 +441,8 @@ class System
             $this->preFlightChecks();
         } catch (Exception $e) {
             error_log(
-                "[IO Exception :: Start Application] (Line ".$e->getLine()." | ".$e->getFile().") - ".$e->getCode(
-                )." | ".$e->getMessage()
+                "[IO Exception :: Start Application] (Line " . $e->getLine() . " | " . $e->getFile(
+                ) . ") - " . $e->getCode() . " | " . $e->getMessage()
             );
             //We errored on preflight. Log the error, attempt to start the base app and return.
             Output::addSystemError($e);
@@ -463,7 +478,7 @@ class System
                 Output::addMessage(
                     'requires_install',
                     "error",
-                    "This Application requires installation. Please set {app: {installRequired: FALSE}} in config, or install the application. Install Path: ".$installPath
+                    "This Application requires installation. Please set {app: {installRequired: FALSE}} in config, or install the application. Install Path: " . $installPath
                 );
             }
 
@@ -493,16 +508,16 @@ class System
             if (is_array($configItem)) {
                 foreach ($configItem as $subItem) {
                     if (!self::isConfigSet($key, $subItem)) {
-                        $missingConfig[] = $key.': '.$subItem;
+                        $missingConfig[] = $key . ': ' . $subItem;
                     }
                 }
             } elseif (!self::isConfigSet($key, $configItem)) {
-                $missingConfig[] = $key.': '.$configItem;
+                $missingConfig[] = $key . ': ' . $configItem;
             }
         }
 
         if ($missingConfig !== []) {
-            throw new Exception("Required application config is missing: (".implode(',', $missingConfig).")");
+            throw new Exception("Required application config is missing: (" . implode(',', $missingConfig) . ")");
         }
     }
 
@@ -535,8 +550,8 @@ class System
                 }
             } catch (Exception $e) {
                 error_log(
-                    "[IO Exception :: Is Installed Check] (Line ".$e->getLine()." | ".$e->getFile().")  - ".$e->getCode(
-                    )." | ".$e->getMessage()
+                    "[IO Exception :: Is Installed Check] (Line " . $e->getLine() . " | " . $e->getFile(
+                    ) . ")  - " . $e->getCode() . " | " . $e->getMessage()
                 );
                 self::$isInstalled = false; //not installed.
             }
@@ -572,7 +587,7 @@ class System
                 return pathUtility::getInstance();
             },
             Singleton::class => function () {
-                return Singleton::getInstance();
+                return Configuration::getInstance();
             },
             Vault::class => function () {
                 return Vault::getInstance();
